Description Usage Arguments Value
View source: R/logisticRegression.R
This function takes in simulation data (see parameter data for more
information) and calls the logSetup function if necessary
before calling the getLogFit function to fit a logistic
regression model predicting the probability of staying based on whether the
last trial was rewarded or not, whether the last trial had a common or rare
transition, and the interaction between the two. It then uses the predict
function and binds the predictions to the original (manipulated with
logSetup) dataframe.
1 |
data |
The data can either be the output of
|
The original (modified with logSetup) data frame plus
two columns predNoStay and predStay.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.